@@ -9,11 +9,17 @@ OC.L10N.register(
     "Move" : "Skuif",
     "Delete" : "Skrap",
     "Select all" : "Kies alle",
+    "Go back" : "Gaan terug",
     "New" : "Nuut",
     "New folder" : "Nuwe vouer",
     "Add a bookmark" : "Voeg 'n boekmerk by",
+    "Delete folder" : "Skrap vouer",
+    "Choose folder" : "Kies vouer",
+    "Submit" : "Dien in",
     "Cancel" : "Kanselleer",
     "Recent" : "Onlangs",
+    "Shared with you" : "Met u gedeel",
+    "Files" : " Lêers",
     "Import" : "Voer In",
     "Export" : "Voer uit",
     "Bookmarklet" : "Boekmerkie",
@@ -21,6 +27,7 @@ OC.L10N.register(
     "Link" : "Skakel",
     "Tags" : "Merkers",
     "Notes" : "Notas",
+    "Open file" : "Open lêer",
     "Owner" : "Eienaar",
     "Share link" : "Deelskakel",
     "Copy link" : "Kopieer skakel",
