@@ -7,22 +7,32 @@ OC.L10N.register(
     "Move" : "نقل",
     "Delete" : "حذف ",
     "Select all" : "تحديد الكل",
+    "Go back" : "العودة",
     "New" : "جديد",
     "New folder" : "مجلد جديد",
+    "Sort by created date" : "فرز حسب تاريخ الإنشاء",
     "Add a bookmark" : "إضافة فاصلة مرجعية",
+    "Rename folder" : "اعادة تسمية المجلد",
+    "Delete folder" : "حذف المجلد",
+    "Submit" : "إرسال ",
     "Cancel" : "إلغاء",
     "Recent" : "الحديثة",
+    "Shared with you" : "تم مشاركتها معك",
+    "Files" : "الملفات",
     "Import" : "استيراد",
     "Export" : "تصدير",
     "Title" : "العنوان",
     "Link" : "الرابط",
     "Tags" : "الوسوم",
     "Notes" : "الملاحظات",
+    "Open file" : "فتح ملف",
+    "Projects" : "المشاريع",
     "Owner" : "المالك",
     "Sharing" : "المشاركة",
     "Share link" : "مشاركة الرابط",
     "Copy link" : "انسخ الرابط",
     "Allow editing" : "السماح بالتعديلات",
+    "Allow resharing" : "السماح بإعادة المشاركة ",
     "Link copied" : "نُسِخ الرابط",
     "Privacy" : "الخصوصية",
     "Previews" : "المعاينات",
