@@ -6,22 +6,30 @@ OC.L10N.register(
     "Move" : "Mover",
     "Delete" : "Desaniciar",
     "Select all" : "Esbillar too",
+    "Go back" : "Dir p'atrás",
     "New" : "Nuevu",
     "New folder" : "Carpeta nueva",
+    "Rename folder" : "Renomar carpeta",
+    "Delete folder" : "Desaniciar",
+    "Choose folder" : "Escoyer carpeta",
     "Submit" : "Unviar",
     "Cancel" : "Encaboxar",
     "Recent" : "Reciente",
+    "Shared with you" : "Shared with you",
+    "Files" : "Ficheros",
     "Import" : "Importar",
     "Export" : "Esportar",
     "Title" : "Títulu",
     "Link" : "Link",
     "Tags" : "Etiquetes",
     "Notes" : "Notes",
+    "Open file" : "Abrir ficheru",
     "Owner" : "Owner",
     "Sharing" : "Compartiendo",
     "Share link" : "Share link",
     "Copy link" : "Copiar enllaz",
     "Allow editing" : "Permitir edición",
+    "Allow resharing" : "Permitir re-compartición",
     "Folder" : "Carpeta",
     "Save" : "Guardar"
 },
