@@ -8,7 +8,11 @@ OC.L10N.register(
     "Select all" : "Hamısıı seç",
     "New" : "Yeni",
     "New folder" : "Yeni qovluq",
+    "Rename folder" : "Qovluğun adını dəyiş",
+    "Delete folder" : "Qovluğu sil",
     "Cancel" : "Dayandır",
+    "Shared with you" : "Shared with you",
+    "Files" : "Fayllar",
     "Import" : "Əlavə et",
     "Export" : "Çıxarış",
     "Title" : "Başlıq",
@@ -19,6 +23,7 @@ OC.L10N.register(
     "Sharing" : "Paylaşılır",
     "Share link" : "Linki yayımla",
     "Copy link" : "linki nüsxələ",
+    "Allow resharing" : "Yenidən paylaşıma izin",
     "Folder" : "Qovluq",
     "Save" : "Saxla"
 },
