@@ -5,16 +5,22 @@ OC.L10N.register(
     "Rename" : "পূনঃনামকরণ",
     "Move" : "Move",
     "Delete" : "মুছে",
+    "Go back" : "ফিরে যাও",
     "New" : "নতুন",
     "New folder" : "নতুন ফোল্ডার",
+    "Rename folder" : "ফোল্ডার পূনঃনামকরণ কর",
+    "Delete folder" : "ফোল্ডার মোছ",
     "Cancel" : "বাতির",
     "Recent" : "সাম্প্রতিক",
+    "Shared with you" : "Shared with you",
+    "Files" : "ফাইল",
     "Import" : "আমদানি",
     "Export" : "রপ্তানি",
     "Title" : "শিরোনাম",
     "Link" : "Link",
     "Tags" : "ট্যাগ",
     "Notes" : "নোট",
+    "Open file" : "খোলা ফাইল",
     "Owner" : "Owner",
     "Sharing" : "ভাগাভাগিরত",
     "Share link" : "লিংক ভাগাভাগি করেন",
