@@ -8,18 +8,26 @@ OC.L10N.register(
     "Select all" : "Dibab pep tra",
     "New" : "Nevez",
     "New folder" : "Heuliad nevez",
+    "Sort by created date" : "Renkañ dre deizat krouidigezh",
+    "Delete folder" : "Dilemel an teuliad",
     "Submit" : "Kinnig",
     "Cancel" : "Arrest",
     "Recent" : "Nevez",
+    "Shared with you" : "Rannet ganeoc'h",
+    "Files" : "Restroù",
     "Broken links" : "Liammoù toret",
     "Import" : "Emporzhiañ ",
+    "Title" : "Titl",
     "Link" : "Liamm",
     "Tags" : "Klavioù",
+    "Open file" : "Digeriñ ur restr",
+    "Projects" : "Raktres",
     "Owner" : "Perc'henner",
     "Sharing" : "Rannan",
     "Share link" : "Rannan liamm",
     "Copy link" : "Kopiañ al liamm",
     "Allow editing" : "Cheñchamentoù aotreet",
+    "Allow resharing" : "Aotrea an adrannañ",
     "Link copied" : "Liamm eilet",
     "Privacy" : "Prevezder",
     "Folder" : "Teuliad",
