@@ -105,6 +105,7 @@ OC.L10N.register(
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Movent %n preferit","Movent %n preferits"],
     "All bookmarks" : "Totes les adreces d'interès",
     "Recent" : "Recents",
+    "Shared with you" : "Compartit amb vós",
     "Files" : "Fitxers",
     "Broken links" : "Enllaços trencats",
     "New tag" : "Nova etiqueta",
@@ -130,6 +131,7 @@ OC.L10N.register(
     "Title" : "Títol",
     "Link" : "Enllaç",
     "Untitled folder" : "Carpeta sense nom",
+    "Root folder" : "Carpeta d'arrel",
     "Tags" : "Etiquetes",
     "Select tags and create new ones" : "Seleccioneu etiquetes i creeu-ne de noves",
     "Notes" : "Notes",
@@ -137,6 +139,7 @@ OC.L10N.register(
     "Archived file" : "Obre el fitxer arxivat",
     "Open file" : "Obre un fitxer",
     "Open file location" : "Obre la ubicació del fitxer",
+    "Projects" : "Projectes",
     "Created {time} ago" : "Creat fa {time}",
     "Created on {date}" : "Creat en {date}",
     "Owner" : "Propietari",
