@@ -5,10 +5,13 @@ OC.L10N.register(
     "Rename" : "Ailenwi",
     "Move" : "Symud",
     "Delete" : "Dileu",
+    "Go back" : "Nôl",
     "New" : "Newydd",
     "New folder" : "Ffolder newydd",
     "Cancel" : "Diddymu",
     "Recent" : "Diweddar",
+    "Shared with you" : "Shared with you",
+    "Files" : "Ffeiliau",
     "Import" : "Mewnforio",
     "Export" : "Allforio",
     "Title" : "Teitl",
@@ -18,6 +21,8 @@ OC.L10N.register(
     "Owner" : "Owner",
     "Share link" : "Rhannu dolen",
     "Copy link" : "Copïo dolen",
+    "Allow editing" : "Caniatáu golygu",
+    "Link copied" : "Dolen wedi'i gopïo",
     "Folder" : "Plygell",
     "Save" : "Cadw"
 },
