@@ -55,6 +55,7 @@ OC.L10N.register(
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Επιλέχθηκε %n σελιδοδείκτης","Επιλέχθηκαν %n σελιδοδείκτες"],
     "_Selected %n folder_::_Selected %n folders_" : ["Επιλέχθηκε %n σελιδοδείκτης","Επιλέχθηκαν %n σελιδοδείκτες"],
     "Go back" : "Επιστροφή",
+    "Share folder" : "Διαμοιρασμός φακέλου",
     "Select one or more tags" : "Επιλέξτε μία ή περισσότερες ετικέτες",
     "New" : "Νέα",
     "New bookmark" : "Νέος σελιδοδείκτης",
@@ -95,6 +96,7 @@ OC.L10N.register(
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Μετακίνηση %n σελιδοδείκτη","Μετακίνηση %n σελιδοδεικτών"],
     "All bookmarks" : "Όλοι οι σελιδοδείκτες",
     "Recent" : "Πρόσφατα",
+    "Shared with you" : "Διαμοιράστηκε με σας",
     "Files" : "Αρχεία",
     "Broken links" : "Κατεστραμμένοι σύνδεσμοι",
     "New tag" : "Νέα ετικέτα",
@@ -115,6 +117,7 @@ OC.L10N.register(
     "Please select \"Add to home screen\" in your browser menu" : "Παρακαλούμε επιλέξτε «Προσθήκη στην αρχική οθόνη» από το μενού του περιηγητή",
     "Title" : "Τίτλος",
     "Link" : "Σύνδεσμος",
+    "Root folder" : "Αρχικός φάκελος",
     "Tags" : "Ετικέτες",
     "Select tags and create new ones" : "Επιλέξτε ετικέτες και δημιουργήστε νέες",
     "Notes" : "Σημειώσεις",
@@ -122,6 +125,7 @@ OC.L10N.register(
     "Archived file" : "Αρχειοθετημένο αρχείο",
     "Open file" : "Άνοιγμα αρχείου",
     "Open file location" : "Άνοιγμα τοποθεσίας αρχείου",
+    "Projects" : "Projects",
     "Created {time} ago" : "Δημιουργήθηκε πριν {time}",
     "Created on {date}" : "Δημιουργήθηκε στις {date}",
     "Owner" : "Κάτοχος",
