@@ -10,25 +10,34 @@ OC.L10N.register(
     "Move" : "Move",
     "Delete" : "Delete",
     "Select all" : "Select all",
+    "Go back" : "Go back",
     "New" : "New",
     "New folder" : "New folder",
     "Add a bookmark" : "Add a bookmark",
+    "Rename folder" : "Rename folder",
+    "Delete folder" : "Delete folder",
+    "Choose folder" : "Choose folder",
     "Submit" : "Submit",
     "Cancel" : "Cancel",
     "All bookmarks" : "All bookmarks",
     "Recent" : "Recent",
+    "Shared with you" : "Shared with you",
+    "Files" : "Files",
     "Import" : "Import",
     "Export" : "Export",
     "Bookmarklet" : "Bookmarklet",
     "Title" : "Title",
     "Link" : "Link",
+    "Root folder" : "Root folder",
     "Tags" : "Tags",
     "Notes" : "Notes",
+    "Open file" : "Open file",
     "Owner" : "Owner",
     "Sharing" : "Sharing",
     "Share link" : "Share link",
     "Copy link" : "Copy link",
     "Allow editing" : "Allow editing",
+    "Allow resharing" : "Allow resharing",
     "Link copied" : "Link copied",
     "Privacy" : "Privacy",
     "Previews" : "Previews",
