@@ -14,12 +14,15 @@ OC.L10N.register(
     "Delete selection" : "Forigi elekton",
     "Select all" : "Elekti ĉion",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["%n legosignon elektitan","%n legosignojn elektitajn"],
+    "Go back" : "Reveni",
     "Select one or more tags" : "Elekti unu aŭ pliajn etikedojn",
     "New" : "Nova",
     "New folder" : "Nova dosierujo",
     "Enter a link" : "Entajpu ligilon",
     "Add a bookmark" : "Aldoni legosignon",
     "Enter folder title" : "Entajpu titolon de la dosierujo",
+    "Rename folder" : "Alinomigi dosierujon",
+    "Delete folder" : "Forigi dosierujon",
     "Submit" : "Sendi",
     "Cancel" : "Nuligi",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Movo de %n dosierujo kaj kelkaj legosignoj","Movo de %n dosierujoj kaj kelkaj legosignoj"],
@@ -27,6 +30,8 @@ OC.L10N.register(
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Movo de %n legosigno","Movo de %n legosignoj"],
     "All bookmarks" : "Ĉiuj legosignoj",
     "Recent" : "Lastaj ŝanĝoj",
+    "Shared with you" : "Kunhavata kun vi",
+    "Files" : "Dosieroj",
     "Untagged" : "Sen etikedo",
     "No bookmarks here" : "Neniu legosigno ĉi tie",
     "Import" : "Importi",
@@ -37,14 +42,17 @@ OC.L10N.register(
     "Add to {instanceName}" : "Aldoni al {instanceName}",
     "Title" : "Titolo",
     "Link" : "Ligilo",
+    "Root folder" : "Radika dosierujo",
     "Tags" : "Etikedoj",
     "Notes" : "Notoj",
+    "Open file" : "Malfermi dosieron",
     "Owner" : "Posedanto",
     "Sharing" : "Kunhavigo",
     "Select a user or group" : "Elektu uzanton aŭ grupon",
     "Share link" : "Kunhavigi ligilon",
     "Copy link" : "Kopii ligilon",
     "Allow editing" : "Permesi modifon",
+    "Allow resharing" : "Permesi rekunhavigon",
     "Link copied" : "Ligilo kopiita",
     "Privacy" : "Privateco",
     "Bookmarks will try to access web pages that you add to automatically add information about them." : "„Legosignaro“ provos aliri retpaĝojn, kiujn vi aldonas por aldoni aŭtomate informojn pri ili.",
