@@ -6,11 +6,17 @@ OC.L10N.register(
     "Move" : "Mover",
     "Delete" : "Eliminar",
     "Select all" : "Seleccionar todo",
+    "Go back" : "Regresar",
     "New" : "Nuevo",
     "New folder" : "Carpeta nueva",
+    "Rename folder" : "Renombrar carpeta",
+    "Delete folder" : "Borrar carpeta",
+    "Choose folder" : "Elegir carpeta",
     "Submit" : "Enviar",
     "Cancel" : "Cancelar",
     "Recent" : "Reciente",
+    "Shared with you" : "Compartido con usted",
+    "Files" : "Archivos",
     "Import" : "Importar",
     "Export" : "Exportar",
     "Bookmarklet" : "Marcador a código",
@@ -18,14 +24,16 @@ OC.L10N.register(
     "Link" : "Link",
     "Tags" : "Etiquetas",
     "Notes" : "Notas",
+    "Open file" : "Abrir archivo",
     "Owner" : "Dueño",
     "Sharing" : "Compartiendo",
     "Share link" : "Compartir enlace",
     "Copy link" : "Copiar enlace",
     "Allow editing" : "Permitir edición",
+    "Allow resharing" : "Permitir volver a compartir",
     "Link copied" : "Link copiado",
     "Privacy" : "Privacidad",
     "Folder" : "Carpeta",
     "Save" : "Guardar"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
