@@ -10,13 +10,19 @@ OC.L10N.register(
     "Move" : "Mover",
     "Delete" : "Borrar",
     "Select all" : "Seleccionar todo",
+    "Go back" : "Regresar",
     "New" : "Nuevo",
     "New folder" : "Carpeta nueva ",
     "Add a bookmark" : "Agregar un marcador",
+    "Rename folder" : "Renombrar carpeta",
+    "Delete folder" : "Borrar carpeta",
+    "Choose folder" : "Seleccioanr carpeta",
     "Submit" : "Enviar",
     "Cancel" : "Cancelar",
     "All bookmarks" : "Todos los marcadores",
     "Recent" : "Reciente",
+    "Shared with you" : "Compartido con usted",
+    "Files" : "Archivos",
     "Import" : "Importar",
     "Export" : "Exportar",
     "Bookmarklet" : "Marcador a código ",
@@ -24,15 +30,17 @@ OC.L10N.register(
     "Link" : "Liga",
     "Tags" : "Etiquetas",
     "Notes" : "Notas",
+    "Open file" : "Abrir archivo",
     "Owner" : "Dueño",
     "Sharing" : "Compartiendo",
     "Share link" : "Compartir liga",
     "Copy link" : "Copiar liga",
     "Allow editing" : "Permitir edición",
+    "Allow resharing" : "Permitir volver a compartir",
     "Link copied" : "Vinculo copiado",
     "Privacy" : "Privacidad",
     "This URL is already bookmarked! Overwrite?" : "¡Esta URL ya está marcada! ¿Quieres sobreescribirlo?",
     "Folder" : "Carpeta",
     "Save" : "Guardar"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
