@@ -7,21 +7,29 @@ OC.L10N.register(
     "Delete" : "Kustuta",
     "Delete selection" : "Kustuta valik",
     "Select all" : "Vali kõik",
+    "Go back" : "Mine tagasi",
     "New" : "Uus",
     "New folder" : "Uus kaust",
+    "Rename folder" : "Nimeta kaust ümber",
+    "Delete folder" : "Kustuta kaust",
+    "Choose folder" : "Vali kaust",
     "Cancel" : "Loobu",
     "Recent" : "Hiljutised",
+    "Shared with you" : "Sinuga jagatud",
+    "Files" : "Failid",
     "Import" : "Impordi",
     "Export" : "Ekspordi",
     "Title" : "Pealkiri",
     "Link" : "Link",
     "Tags" : "Sildid",
     "Notes" : "Märkmed",
+    "Open file" : "Ava fail",
     "Owner" : "Omanik",
     "Sharing" : "Jagamine",
     "Share link" : "Jaga link",
     "Copy link" : "Kopeeri link",
     "Allow editing" : "Luba muutmine",
+    "Allow resharing" : "Luba edasijagamine",
     "Link copied" : "Link kopeeritud",
     "Privacy" : "Privaatsus",
     "Folder" : "Kaust",
