@@ -14,18 +14,24 @@ OC.L10N.register(
     "Delete selection" : "انتخاب را حذف کنید",
     "Select all" : "انتخاب همه",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["انتخاب شده %n نشانک","انتخاب شده %n نشانک های"],
+    "Go back" : "برگرد",
+    "Share folder" : "اشتراک‌گذاری پوشه",
     "Select one or more tags" : "یک یا چند تگ را انتخاب کنید",
     "New" : "جدید",
     "New folder" : "پوشه جدید",
     "Enter a link" : "پیوند را وارد کنید",
     "Add a bookmark" : "یک نشانک اضافه کنید",
     "Enter folder title" : "عنوان پوشه را وارد کنید",
+    "Rename folder" : "تغییر نام پوشه",
+    "Delete folder" : "حذف پوشه",
     "Submit" : "ارسال",
     "Cancel" : "لغو",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["در حال انتقال %nپوشه ها و برخی نشانک ها","در حال انتقال %n پوشه ها و برخی نشانک ها"],
     "_Moving %n folder_::_Moving %n folders_" : ["در حال انتقال %n پوشه","در حال انتقال %n پوشه ها"],
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["در حال انتقال %n نشانک","در حال انتقال %n نشانک ها"],
     "Recent" : "اخیر",
+    "Shared with you" : "با شما به اشتراک گذاشته شده است",
+    "Files" : "فایل ها",
     "Untagged" : "غیرقابل تشخیص",
     "No bookmarks here" : "در اینجا هیچ نشانک وجود ندارد",
     "Import" : "وارد کردن",
@@ -36,14 +42,18 @@ OC.L10N.register(
     "Add to {instanceName}" : "افزودن به {instanceName}",
     "Title" : "عنوان",
     "Link" : "Link",
+    "Root folder" : "پوشهٔ ریشه",
     "Tags" : "برچسب‌ها",
     "Notes" : "یادداشت ها",
+    "Open file" : "باز کردن فایل",
+    "Projects" : "پروژه ها",
     "Owner" : "صاحب",
     "Sharing" : "اشتراک گذاری",
     "Select a user or group" : "کاربر یا گروهی را انتخاب کنید",
     "Share link" : "لینک را به اشتراک بگذارید",
     "Copy link" : "کپی کردن لینک",
     "Allow editing" : "اجازه‌ی ویرایش",
+    "Allow resharing" : "مجاز به اشتراک گذاری مجدد",
     "Link copied" : "پیوند کپی شد",
     "Privacy" : "حریم خصوصی",
     "Bookmarks will try to access web pages that you add to automatically add information about them." : "نشانک ها سعی می کنند به صفحات وب اضافه شده دسترسی پیدا کنند تا به طور خودکار اطلاعات مربوط به آنها اضافه شود.",
