@@ -27,6 +27,7 @@ OC.L10N.register(
     "Someone unshared folder \"%s\" with you" : "Quelqu'un a annulé le partage du dossier \"%s\" avec vous",
     "No file provided for import" : "Aucun fichier à importer.",
     "Unsupported file type for import" : "Type de fichier non pris en charge",
+    "Bookmarks Backups" : "Sauvegarde de favoris",
     "Bookmarks shared by %s" : "Favoris partagés par %s",
     "Frequent bookmarks" : "Favoris fréquents",
     "Recent bookmarks" : "Favoris récents",
@@ -57,8 +58,8 @@ OC.L10N.register(
     "Cancel selection" : "Annuler la sélection",
     "Selected {folders} folders and {bookmarks} bookmarks" : "{folders} dossiers et {bookmarks} marque-pages sélectionnés",
     "Do you really want to delete these items?" : "Voulez-vous vraiment supprimer ces éléments?",
-    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["%n favori sélectionné","%n favoris sélectionnés"],
-    "_Selected %n folder_::_Selected %n folders_" : ["%n  dossier sélectionné","%n dossiers sélectionnés"],
+    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["%n favori sélectionné","%n favoris sélectionnés","%n favoris sélectionnés"],
+    "_Selected %n folder_::_Selected %n folders_" : ["%n  dossier sélectionné","%n dossiers sélectionnés","%n dossiers sélectionnés"],
     "Go back" : "Revenir en arrière",
     "Share folder" : "Partager ce dossier",
     "Select one or more tags" : "Sélectionnez une ou plusieurs étiquettes",
@@ -75,13 +76,14 @@ OC.L10N.register(
     "Sort by click count" : "Trier par nombre de cliques",
     "Sort by manual order" : "Trier manuellement",
     "RSS feed copied" : "Flux RSS copié",
-    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Ajout de %n favori au nouveau dossier","Ajout de %n favoris au nouveau dossier"],
+    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Ajout de %n favori au nouveau dossier","Ajout de %n favoris au nouveau dossier","Ajout de %n favoris au nouveau dossier"],
     "Enter a link" : "Saisissez un lien",
     "Enter a title" : "Saisissez un titre",
     "No bookmarks found" : "Aucun favori",
     "{folders} folders and {bookmarks} bookmarks" : "{folders} dossiers et {bookmarks} favoris",
-    "_%n bookmark_::_%n bookmarks_" : ["%n favori","%n favoris"],
-    "_%n folder_::_%n folders_" : ["%n dossier","%n dossiers"],
+    "_%n bookmark_::_%n bookmarks_" : ["%n favori","%n favoris","%n favoris"],
+    "_%n folder_::_%n folders_" : ["%n dossier","%n dossiers","%n dossiers"],
+    "Welcome to Bookmarks" : "Bienvenu dans les favoris",
     "Add a bookmark" : "Ajouter un favori",
     "Import bookmarks" : "Importer des favoris",
     "Sync with your browser" : "Synchronisez avec votre navigateur",
@@ -100,12 +102,14 @@ OC.L10N.register(
     "Importing bookmarks" : "Import des favoris",
     "Moving selection" : "Déplacement de la sélection",
     "Adding selection to folders" : "Ajout de la sélection aux dossiers",
-    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Déplacement de %n dossier et de certains signets","Déplacement de %n dossiers et de certains signets"],
-    "_Moving %n folder_::_Moving %n folders_" : ["Déplacement de %n dossier","Déplacement de %n dossiers"],
-    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Déplacement de %n favori","Déplacement de %n favoris"],
+    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Déplacement de %n dossier et de certains signets","Déplacement de %n dossiers et de certains signets","Déplacement de %n dossiers et de certains signets"],
+    "_Moving %n folder_::_Moving %n folders_" : ["Déplacement de %n dossier","Déplacement de %n dossiers","Déplacement de %n dossiers"],
+    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Déplacement de %n favori","Déplacement de %n favoris","Déplacement de %n favoris"],
     "All bookmarks" : "Tous les favoris",
     "Recent" : "Récent",
+    "Shared with you" : "Partagés avec vous",
     "Files" : "Fichiers",
+    "Duplicates" : "Duplicates",
     "Broken links" : "Liens brisés",
     "New tag" : "Nouvelle étiquette",
     "Search tags" : "Rechercher des étiquettes",
@@ -113,11 +117,15 @@ OC.L10N.register(
     "{used} bookmarks of {available} available" : "{used} favoris sur {available} disponibles",
     "No bookmarked files" : "Aucun fichier en favori",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Les favoris vers des fichiers comme des photos ou des PDF seront automatiquement enregistrés dans vos fichiers Nextcloud, pour que vous puissiez y accéder même quand le lien est hors connexion.",
+    "No broken links" : "Aucun lien brisé",
+    "No shared folders" : "Aucun dossier partagé",
+    "No duplicated bookmarks" : "Aucun favori en double",
     "No bookmarks here" : "Aucun favori ici",
     "Import" : "Importer",
     "Export" : "Exporter",
     "Archive path" : "Archiver le chemin d'accès",
     "Enter the path of a folder in your Files where bookmarked files should be stored." : "Entrer le chemin d’accès d’un dossier dans vos fichiers où les fichiers favoris doivent être stockés.",
+    "Backups" : "Sauvegardes",
     "Client apps" : "Applications clientes",
     "Also check out the collection of client apps that integrate with this app: " : "Découvrez également une gamme d'applications client qui s'intègrent à cette application : ",
     "Install web app on device" : "Installer l’application web sur l’appareil",
@@ -130,6 +138,7 @@ OC.L10N.register(
     "Title" : "Titre",
     "Link" : "Lien",
     "Untitled folder" : "Dossier sans titre",
+    "Root folder" : "Dossier racine",
     "Tags" : "Étiquettes",
     "Select tags and create new ones" : "Sélectionner des étiquettes ou en créer de nouvelles",
     "Notes" : "Notes",
@@ -137,6 +146,7 @@ OC.L10N.register(
     "Archived file" : "Fichier archivé",
     "Open file" : "Ouvrir le fichier",
     "Open file location" : "Ouvrir l’emplacement du fichier",
+    "Projects" : "Projets",
     "Created {time} ago" : "Créé il y a {time}",
     "Created on {date}" : "Créé le {date}",
     "Owner" : "Propriétaire",
@@ -180,8 +190,10 @@ OC.L10N.register(
     "Root Folder" : "Dossier racine",
     "Save" : "Enregistrer",
     "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "L’accès au réseau est désactivé par défaut. Rendez-vous dans les paramètres administrateur de cette application pour autoriser le téléchargement de prévisualisations et de favicons.",
+    "Link to a bookmark folder" : "Lien vers un dossier de favoris",
     "Failed to count unavailable bookmarks" : "Impossible de compter les favoris indisponibles",
     "Failed to count archived bookmarks" : "Impossible de compter les favoris archivés",
+    "Failed to count duplicated bookmarks" : "Impossible de compter les favoris dupliqués",
     "Failed to load bookmark" : "Impossible de charger les favoris",
     "Failed to find existing bookmark" : "Impossible de trouver un signet existant",
     "Failed to create bookmark" : "Echec de la création du favori",
@@ -199,6 +211,7 @@ OC.L10N.register(
     "Failed to load setting {key}" : "Échec du chargement du paramètre {key}",
     "Failed to update share {shareId}" : "Impossible de mettre à jour le partage {shareId}",
     "Failed to delete share {shareId}" : "Impossible de supprimer le partage {shareId}",
+    "No links found in this message" : "Aucun lien trouvé dans ce message",
     "Bookmarks feed" : "Flux de suivi"
 },
-"nplurals=2; plural=(n > 1);");
+"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
