@@ -28,6 +28,7 @@ OC.L10N.register(
     "No file provided for import" : "Non forneceu ningún ficheiro para importar",
     "Unsupported file type for import" : "Tipo de ficheiro non admitido para importar",
     "Bookmarks shared by %s" : "Marcador compartido por %s",
+    "Recent bookmarks" : "Marcadores recentes",
     "Bookmark" : "Marcador",
     "Bookmark deleted" : "Eliminouse o marcador",
     "Bookmark created" : "Creouse o marcador",
@@ -53,10 +54,12 @@ OC.L10N.register(
     "Do you really want to delete these items?" : "Confirma que quere eliminar estes elementos?",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Seleccionado %nmarcador","Seleccionados %n marcadores"],
     "_Selected %n folder_::_Selected %n folders_" : ["%n cartafol seleccionado"," %n cartafoles seleccionados"],
+    "Go back" : "Volver",
     "Select one or more tags" : "Seleccione unha ou máis etiquetas",
     "New" : "Novo",
     "New bookmark" : "Novo marcador",
     "New folder" : "Novo cartafol",
+    "Sort by created date" : "Ordenar pola data de creación.",
     "RSS feed copied" : "Fonte RSS copiada",
     "Enter a link" : "Introduza unha ligazón.",
     "Enter a title" : "Introduza o título",
@@ -67,7 +70,10 @@ OC.L10N.register(
     "Select folder" : "Cartafol seleccionado",
     "Enter folder title" : "Introduza o título do cartafol",
     "Shared by {user}" : "Compartido por {user}",
+    "Rename folder" : "Renomear o cartafol",
+    "Delete folder" : "Eliminar cartafol",
     "Do you really want to delete this folder?" : "Confirma que quere eliminar este cartafol?",
+    "Choose folder" : "Escoller cartafol",
     "Submit" : "Enviar",
     "Cancel" : "Cancelar",
     "Deleting bookmarks" : "Eliminando os marcadores",
@@ -79,6 +85,8 @@ OC.L10N.register(
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Movendo %n marcador","Movendo %n marcadores"],
     "All bookmarks" : "Todos os marcadores",
     "Recent" : "Recente",
+    "Shared with you" : "Compartido con vostede",
+    "Files" : "Ficheiros",
     "Broken links" : "Ligazóns rachadas",
     "Untagged" : "Sen etiquetar",
     "{used} bookmarks of {available} available" : "{used} marcadores de {available} disponíbel/is",
@@ -95,10 +103,13 @@ OC.L10N.register(
     "Please select \"Add to home screen\" in your browser menu" : "Seleccione «Engadir na pantalla de inicio» no menú do seu navegador",
     "Title" : "Título",
     "Link" : "Ligazón",
+    "Root folder" : "Cartafol raíz",
     "Tags" : "Etiquetas",
     "Select tags and create new ones" : "Seleccionar etiquetas e crear outras novas",
     "Notes" : "Notas",
     "Notes for this bookmark …" : "Notas para este marcador…",
+    "Open file" : "Abrir ficheiro",
+    "Projects" : "Proxectos",
     "Owner" : "Propietario",
     "Sharing" : "Compartindo",
     "Select a user or group" : "Seleccionar un usuario ou grupo",
@@ -108,6 +119,7 @@ OC.L10N.register(
     "Delete link" : "Eliminar ligazón",
     "Create public link" : "Crear ligazón pública",
     "Allow editing" : "Permitir a edición",
+    "Allow resharing" : "Permitir compartir",
     "Remove share" : "Retirar a compartición",
     "Link copied" : "Ligazón copiada",
     "Privacy" : "Privacidade",
