@@ -41,6 +41,7 @@ OC.L10N.register(
     "Do you really want to delete these items?" : "למחוק את הפריטים האלה?",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["סימנייה אחת נבחרה","%n סימניות נבחרו","%n סימניות נבחרו","%n סימניות נבחרו"],
     "_Selected %n folder_::_Selected %n folders_" : ["נבחרה תיקייה %n","נבחרו %n תיקיות","נבחרו %n תיקיות","נבחרו %n תיקיות"],
+    "Go back" : "חזרה",
     "Select one or more tags" : "יש לבחור תגית אחת או יותר",
     "New" : "חדש",
     "New bookmark" : "סימנייה חדשה",
@@ -53,7 +54,10 @@ OC.L10N.register(
     "Select folder" : "בחירת תיקייה",
     "Enter folder title" : "נא למלא כותרת לתיקייה",
     "Shared by {user}" : "שותפה על ידי {user}",
+    "Rename folder" : "שינוי שם תיקייה",
+    "Delete folder" : "מחיקת תיקייה",
     "Do you really want to delete this folder?" : "למחוק את התיקייה הזאת?",
+    "Choose folder" : "בחירת תיקייה",
     "Submit" : "שליחה",
     "Cancel" : "ביטול",
     "Deleting bookmarks" : "הסימניות נמחקות",
@@ -65,6 +69,7 @@ OC.L10N.register(
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["סימנייה אחת מועברת","%n סימניות מועברות","%n סימניות מועברות","%n סימניות מועברות"],
     "All bookmarks" : "כל הסימניות",
     "Recent" : "אחרונים",
+    "Shared with you" : "משותף אתך",
     "Files" : "קבצים",
     "Broken links" : "קישורים פגומים",
     "Untagged" : "ללא תגית",
@@ -81,9 +86,12 @@ OC.L10N.register(
     "Please select \"Add to home screen\" in your browser menu" : "נא לבחור באפשרות „הוספה למסך הבית” בתפריט הדפדפן שלך",
     "Title" : "תפקיד",
     "Link" : "קישור",
+    "Root folder" : "תיקיית בסיס",
     "Tags" : "תגיות",
     "Select tags and create new ones" : "בחירת תגיות ויצירת חדשות",
     "Notes" : "הערות",
+    "Open file" : "פתיחת קובץ",
+    "Projects" : "מיזמים",
     "Created {time} ago" : "נוצר לפני {time}",
     "Owner" : "בעלות",
     "Sharing" : "שיתוף",
@@ -93,6 +101,7 @@ OC.L10N.register(
     "Delete link" : "מחיקת קישור",
     "Create public link" : "יצירת קישור ציבורי",
     "Allow editing" : "לאפשר עריכה",
+    "Allow resharing" : "לאפשר שיתוף מחדש",
     "Remove share" : "הסרת שיתוף",
     "Link copied" : "הקישור הועתק",
     "Privacy" : "פרטיות",
