@@ -105,6 +105,7 @@ OC.L10N.register(
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Premještanje %n knjižne oznake","Premještanje %n knjižne oznake","Premještanje %n knjižnih oznaka"],
     "All bookmarks" : "Sve knjižne oznake",
     "Recent" : "Nedavni",
+    "Shared with you" : "Podijeljeno s vama",
     "Files" : "Datoteke",
     "Broken links" : "Prekinute poveznice",
     "New tag" : "Nova oznaka",
@@ -130,6 +131,7 @@ OC.L10N.register(
     "Title" : "Naslov",
     "Link" : "Poveznica",
     "Untitled folder" : "Mapa bez naslova",
+    "Root folder" : "Korijenska mapa",
     "Tags" : "Oznake",
     "Select tags and create new ones" : "Odaberite oznake i stvorite nove",
     "Notes" : "Bilješke",
@@ -137,6 +139,7 @@ OC.L10N.register(
     "Archived file" : "Arhivirana datoteka",
     "Open file" : "Otvori datoteku",
     "Open file location" : "Otvori lokaciju datoteke",
+    "Projects" : "Projekti",
     "Created {time} ago" : "Stvoreno prije {time}",
     "Created on {date}" : "Stvoreno {date}",
     "Owner" : "Vlasnik",
