@@ -6,16 +6,22 @@ OC.L10N.register(
     "Move" : "Mover",
     "Delete" : "Deler",
     "Select all" : "Selectionar toto",
+    "Go back" : "Retornar",
     "New" : "Nove",
     "New folder" : "Nove dossier",
+    "Rename folder" : "Renominar dossier",
+    "Delete folder" : "Deler dossier",
     "Cancel" : "Cancellar",
     "Recent" : "Recente",
+    "Shared with you" : "Compartite con te",
+    "Files" : "Files",
     "Import" : "Importar",
     "Export" : "Exportar",
     "Title" : "Titulo",
     "Link" : "Ligamine",
     "Tags" : "Etiquettas",
     "Notes" : "Notas",
+    "Open file" : "Aperir file",
     "Owner" : "Owner",
     "Sharing" : "Compartente",
     "Share link" : "Compartir ligamine",
