@@ -18,6 +18,7 @@ OC.L10N.register(
     "Cancel selection" : "Batalkan pilihan",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Memilih %n markah"],
     "_Selected %n folder_::_Selected %n folders_" : ["Memilih %n folder"],
+    "Go back" : "Kembali",
     "Select one or more tags" : "Pilih satu atau lebih tag",
     "New" : "Baru",
     "New bookmark" : "Markah baru",
@@ -26,11 +27,15 @@ OC.L10N.register(
     "Add a bookmark" : "Tambahkan markah",
     "Select folder" : "Pilih folder",
     "Shared by {user}" : "Dibagikan oleh {user}",
+    "Rename folder" : "Ubah nama folder",
+    "Delete folder" : "Hapus folder",
     "Cancel" : "Membatalkan",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Memindahkan %n folder dan beberapa markah"],
     "_Moving %n folder_::_Moving %n folders_" : ["Memindahkan %n folder"],
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Memindahkan %n markah"],
     "Recent" : "Terbaru",
+    "Shared with you" : "Shared with you",
+    "Files" : "Berkas",
     "Untagged" : "Belum ada tag",
     "No bookmarks here" : "Tidak ada markah disini",
     "Import" : "Impor",
@@ -38,8 +43,11 @@ OC.L10N.register(
     "Client apps" : "Aplikasi klien",
     "Title" : "Judul",
     "Link" : "Tautan",
+    "Root folder" : "Folder akar",
     "Tags" : "Tag",
     "Notes" : "Catatan",
+    "Open file" : "Membuka berkas",
+    "Projects" : "Proyek",
     "Owner" : "Owner",
     "Sharing" : "Berbagi",
     "Select a user or group" : "Pilih pengguna atau grup",
@@ -49,6 +57,7 @@ OC.L10N.register(
     "Delete link" : "Hapus tautan",
     "Create public link" : "Buat tautan publik",
     "Allow editing" : "Izinkan penyuntingan",
+    "Allow resharing" : "Izinkan pembagian ulang",
     "Link copied" : "Link tersalin",
     "Privacy" : "Privasi",
     "Performance" : "Performa",
