@@ -19,16 +19,21 @@ OC.L10N.register(
     "Selected {folders} folders and {bookmarks} bookmarks" : "Valdar {folders} möppur og {bookmarks} bókamerki",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Valdi %n bókamerki","Valdi %n bókamerki"],
     "_Selected %n folder_::_Selected %n folders_" : ["Valin %n mappa","Valdar %n möppur"],
+    "Go back" : "Fara til baka",
     "Select one or more tags" : "Veldu eitt eða fleiri merki",
     "New" : "Nýtt",
     "New bookmark" : "Nýtt bókamerki",
     "New folder" : "Ný mappa",
+    "Sort by created date" : "Sort by created date",
     "RSS feed copied" : "RSS-fréttastreymi afritað",
     "Enter a link" : "Settu inn slóð",
     "Add a bookmark" : "Bæta við bókamerki",
     "Select folder" : "Veldu möppu",
     "Enter folder title" : "Settu inn heiti möppu",
     "Shared by {user}" : "Deilt af {user}",
+    "Rename folder" : "Endurnefna möppu",
+    "Delete folder" : "Eyða möppu",
+    "Choose folder" : "Veldu möppu",
     "Submit" : "Senda inn",
     "Cancel" : "Hætta við",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Færi %n möppu og einhver bókamerki","Færi %n möppur og einhver bókamerki"],
@@ -36,6 +41,8 @@ OC.L10N.register(
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Færi %n bókamerki","Færi %n bókamerki"],
     "All bookmarks" : "Öll bókamerki",
     "Recent" : "Nýlegt",
+    "Shared with you" : "Deilt með þér",
+    "Files" : "Skrár",
     "Untagged" : "Ómerkt",
     "{used} bookmarks of {available} available" : "{used} bókamerki af {available} tiltækum",
     "No bookmarks here" : "Engin bókamerki hér",
@@ -47,8 +54,11 @@ OC.L10N.register(
     "Add to {instanceName}" : "Bæta við {instanceName}",
     "Title" : "Titill",
     "Link" : "Tengill",
+    "Root folder" : "Rótarmappa",
     "Tags" : "Merki",
     "Notes" : "Minnispunktar",
+    "Open file" : "Opna skrá",
+    "Projects" : "Verkefni",
     "Owner" : "Eigandi",
     "Sharing" : "Deiling",
     "Select a user or group" : "Veldu notanda eða hóp",
@@ -58,6 +68,7 @@ OC.L10N.register(
     "Delete link" : "Eyða tengli",
     "Create public link" : "Búa til opinberan tengil",
     "Allow editing" : "Leyfa breytingar",
+    "Allow resharing" : "Leyfa endurdeilingu",
     "Remove share" : "Fjarlægja sameign",
     "Link copied" : "Tengill afritaður",
     "Privacy" : "Gagnaleynd",
