@@ -57,8 +57,8 @@ OC.L10N.register(
     "Cancel selection" : "Annulla la selezione",
     "Selected {folders} folders and {bookmarks} bookmarks" : "Selezionate {folders} cartelle e {bookmarks} segnalibri",
     "Do you really want to delete these items?" : "Vuoi davvero eliminare questi elementi?",
-    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Selezionato %n segnalibro","Selezionati %n segnalibri"],
-    "_Selected %n folder_::_Selected %n folders_" : ["Selezionata %n cartella","Selezionate %n cartelle"],
+    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Selezionato %n segnalibro","Selezionati %n segnalibri","Selezionati %n segnalibri"],
+    "_Selected %n folder_::_Selected %n folders_" : ["Selezionata %n cartella","Selezionate %n cartelle","Selezionate %n cartelle"],
     "Go back" : "Indietro",
     "Share folder" : "Condividi cartella",
     "Select one or more tags" : "Seleziona una o più etichette",
@@ -75,13 +75,13 @@ OC.L10N.register(
     "Sort by click count" : "Ordina per numero di clic",
     "Sort by manual order" : "Ordina manualmente",
     "RSS feed copied" : "Fonte RSS copiata",
-    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Aggiunta di %n segnalibro alla nuova cartella","Aggiunta di %n segnalibri alla nuova cartella"],
+    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Aggiunta di %n segnalibro alla nuova cartella","Aggiunta di %n segnalibri alla nuova cartella","Aggiunta di %n segnalibri alla nuova cartella"],
     "Enter a link" : "Digita un collegamento",
     "Enter a title" : "Digita un titolo",
     "No bookmarks found" : "Nessun segnalibro trovato",
     "{folders} folders and {bookmarks} bookmarks" : "{folders} cartelle e {bookmarks} segnalibri",
-    "_%n bookmark_::_%n bookmarks_" : ["%n segnalibro","%n segnalibri"],
-    "_%n folder_::_%n folders_" : ["1%n cartella","%n cartelle"],
+    "_%n bookmark_::_%n bookmarks_" : ["%n segnalibro","%n segnalibri","%n segnalibri"],
+    "_%n folder_::_%n folders_" : ["1%n cartella","%n cartelle","%n cartelle"],
     "Welcome to Bookmarks" : "Benvenuto in segnalibri",
     "This app allows you to manage links to your favorite places on the web." : "Questa app ti permette di gestire i link ai tuoi luoghi preferiti sul web.",
     "Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Organizza i tuoi segnalibri in cartelle, etichettali e condividili con gli altri! L'app verifica regolarmente la disponibilità di tutti i tuoi collegamenti e visualizza i collegamenti non disponibili Se aggiungi un collegamento a un file sul Web, il file verrà scaricato automaticamente nei tuoi file Nextcloud. Puoi anche importare i segnalibri esportati da altri servizi o sincronizzare direttamente i segnalibri da tutti i tuoi browser con questa app.",
@@ -103,9 +103,9 @@ OC.L10N.register(
     "Importing bookmarks" : "Importazione segnalibri",
     "Moving selection" : "Spostamento selezione",
     "Adding selection to folders" : "Aggiunta della selezione alle cartelle",
-    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Spostamento di %n cartella e di alcuni segnalibri","Spostamento di %n cartelle e alcuni segnalibri"],
-    "_Moving %n folder_::_Moving %n folders_" : ["Spostamento di %n cartella","Spostamento di %n cartelle"],
-    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Spostamento di %n segnalibro","Spostamento di %n segnalibri"],
+    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Spostamento di %n cartella e di alcuni segnalibri","Spostamento di %n cartelle e alcuni segnalibri","Spostamento di %n cartelle e alcuni segnalibri"],
+    "_Moving %n folder_::_Moving %n folders_" : ["Spostamento di %n cartella","Spostamento di %n cartelle","Spostamento di %n cartelle"],
+    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Spostamento di %n segnalibro","Spostamento di %n segnalibri","Spostamento di %n segnalibri"],
     "All bookmarks" : "Tutti i segnalibri",
     "Recent" : "Recenti",
     "Shared with you" : "Condivisi con te",
@@ -215,4 +215,4 @@ OC.L10N.register(
     "No links found in this message" : "Nessun link trovato in questo messaggio",
     "Bookmarks feed" : "Fonte dei segnalibri"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
