@@ -27,6 +27,7 @@ OC.L10N.register(
     "Someone unshared folder \"%s\" with you" : "誰かがフォルダー「%s」のあなたとの共有を解除しました",
     "No file provided for import" : "インポート用に提供されたファイルがありません",
     "Unsupported file type for import" : "インポートでサポートされていないファイル形式です",
+    "Bookmarks Backups" : "ブックマークのバックアップ",
     "Bookmarks shared by %s" : "%sさんから共有されたブックマーク",
     "Recent bookmarks" : "最新のブックマーク",
     "Bookmark" : "ブックマーク",
@@ -74,6 +75,7 @@ OC.L10N.register(
     "No bookmarks found" : "ブックマークが見つかりません",
     "_%n bookmark_::_%n bookmarks_" : ["%n個のブックマーク"],
     "_%n folder_::_%n folders_" : ["%n 個のフォルダー"],
+    "Welcome to Bookmarks" : "Bookmarksへようこそ",
     "Add a bookmark" : "ブックマークを追加",
     "Import bookmarks" : "ブックマークをインポート",
     "Sync with your browser" : "ブラウザーと同期",
@@ -96,6 +98,7 @@ OC.L10N.register(
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["%n個のブックマークを移動中"],
     "All bookmarks" : "すべてのブックマーク",
     "Recent" : "最新",
+    "Shared with you" : "共有中",
     "Files" : "ファイル",
     "Broken links" : "壊れたリンク",
     "New tag" : "新しいタグ",
@@ -104,10 +107,13 @@ OC.L10N.register(
     "{used} bookmarks of {available} available" : "利用可能ブックマーク数 {available} のうち{used} が使用済み ",
     "No bookmarked files" : "ブックマーク済みファイルがありません",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "写真やPDFといったファイルへのブックマークは、自動的にNextcloudファイルとして保存されるため、リンクがオフラインになっても見つけることができます。",
+    "No broken links" : "壊れたリンクなし",
     "No bookmarks here" : "ブックマークがありません",
     "Import" : "インポート",
     "Export" : "エクスポート",
     "Archive path" : "アーカイブパス",
+    "Backups" : "バックアップ",
+    "Enable bookmarks backups" : "ブックマークのバックアップを有効化",
     "Client apps" : "クライアントアプリ",
     "Also check out the collection of client apps that integrate with this app: " : "このアプリと連携するクライアントアプリもご確認ください：",
     "Install on home screen" : "ホーム画面へインストール",
@@ -116,6 +122,7 @@ OC.L10N.register(
     "Please select \"Add to home screen\" in your browser menu" : "お使いのブラウザーで「ホーム画面に追加」を選択してください",
     "Title" : "タイトル",
     "Link" : "リンク",
+    "Root folder" : "ルートフォルダー",
     "Tags" : "タグ",
     "Select tags and create new ones" : "タグを選択もしくは新規作成",
     "Notes" : "ノート",
@@ -123,6 +130,7 @@ OC.L10N.register(
     "Archived file" : "アーカイブ済みファイル",
     "Open file" : "ファイルを開く",
     "Open file location" : "ファイルの場所を開く",
+    "Projects" : "プロジェクト",
     "Created {time} ago" : "{time} 前に作成した",
     "Owner" : "所有者",
     "Sharing" : "共有中",
@@ -169,6 +177,7 @@ OC.L10N.register(
     "Failed to create bookmark" : "ブックマークの作成に失敗しました",
     "Failed to save bookmark" : "ブックマークの保存に失敗しました",
     "Failed to move bookmark" : "ブックマークの移動に失敗しました",
+    "Failed to copy bookmark" : "ブックマークのコーピーに失敗しました",
     "Failed to delete bookmark" : "ブックマークの削除に失敗しました",
     "Failed to rename tag" : "タグ名の変更に失敗しました",
     "Failed to load tags" : "タグの読込に失敗しました",
@@ -180,6 +189,7 @@ OC.L10N.register(
     "Failed to load setting {key}" : "設定の読込に失敗しました {key}",
     "Failed to update share {shareId}" : "共有の更新に失敗しました {shareId}",
     "Failed to delete share {shareId}" : "共有の削除に失敗しました {shareId}",
+    "No links found in this message" : "このメッセージの中にリンクを見つかりません",
     "Bookmarks feed" : "ブックマークフィード"
 },
 "nplurals=1; plural=0;");
