@@ -9,12 +9,18 @@ OC.L10N.register(
     "Move" : "გადატანა",
     "Delete" : "წაშლა",
     "Select all" : "ყველას არჩევა",
+    "Go back" : "უკან დაბრუნება",
     "New" : "ახალი",
     "New folder" : "ახალი დირექტორია",
     "Add a bookmark" : "სანიშნის დამატება",
+    "Rename folder" : "ფოლდერის სახელის გადარქმევა",
+    "Delete folder" : "დირექტორიის გაუქმება",
+    "Choose folder" : "აირჩიეთ დირექტორია",
     "Submit" : "გაგზავნა",
     "Cancel" : "უარყოფა",
     "Recent" : "ახალი",
+    "Shared with you" : "გაზიარებული თქვენთან",
+    "Files" : "ფაილები",
     "Import" : "იმპორტი",
     "Export" : "ექსპორტი",
     "Bookmarklet" : "Bookmarklet-ი",
@@ -22,11 +28,13 @@ OC.L10N.register(
     "Link" : "ბმული",
     "Tags" : "ტეგები",
     "Notes" : "ჩანაწერები",
+    "Open file" : "ფაილის გახსნა",
     "Owner" : "მფლობელი",
     "Sharing" : "გაზიარება",
     "Share link" : "ბმულის გაზიარება",
     "Copy link" : "ბმულის კოპირება",
     "Allow editing" : "შეცვლის ნების დართვა",
+    "Allow resharing" : "ხელახალი გაზიარების დაშვება",
     "Privacy" : "კონფიდენციალურობა",
     "This URL is already bookmarked! Overwrite?" : "ეს URL უკვე მონიშნულია! გადავწეროთ?",
     "Folder" : "დირექტორია",
