@@ -7,7 +7,11 @@ OC.L10N.register(
     "Delete" : "លុប",
     "New" : "ថ្មី",
     "New folder" : "ថត​ថ្មី",
+    "Rename folder" : "ប្ដូរ​ឈ្មោះ​ថត",
+    "Delete folder" : "លុប​ថត",
     "Cancel" : "បោះបង់",
+    "Shared with you" : "Shared with you",
+    "Files" : "ឯកសារ",
     "Import" : "នាំយកចូល",
     "Export" : "នាំចេញ",
     "Title" : "ចំណងជើង",
@@ -17,6 +21,8 @@ OC.L10N.register(
     "Owner" : "Owner",
     "Sharing" : "ការ​ចែក​រំលែក",
     "Share link" : "Share link",
+    "Copy link" : "ចម្លងតំណ",
+    "Allow resharing" : "អនុញ្ញាត​ការ​ចែក​រំលែក​ម្ដង​ទៀត",
     "Folder" : "ថត",
     "Save" : "រក្សាទុក"
 },
