@@ -14,17 +14,24 @@ OC.L10N.register(
     "Select all" : "Select all",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["선택된 %n 북마크들"],
     "_Selected %n folder_::_Selected %n folders_" : ["선택된 %n 폴더들"],
+    "Go back" : "뒤로 가기",
     "New" : "새로 만들기",
     "New bookmark" : "새로운 북마크",
     "New folder" : "새 폴더",
+    "Sort by created date" : "만들어진 순서로 정렬",
     "Enter a link" : "링크를 입력하시오.",
     "Add a bookmark" : "북마크 추가",
     "Select folder" : "폴더 선택",
     "Enter folder title" : "폴더명을 입력하시오.",
     "Shared by {user}" : "{user}가 공유한",
+    "Rename folder" : "폴더 이름 바꾸기",
+    "Delete folder" : "폴더 삭제",
+    "Choose folder" : "폴더 선택",
     "Submit" : "제출",
     "Cancel" : "취소",
     "Recent" : "최근 항목",
+    "Shared with you" : "나와 공유됨",
+    "Files" : "파일",
     "Untagged" : "태그 지우기",
     "Import" : "가져오기",
     "Export" : "내보내기",
@@ -32,14 +39,18 @@ OC.L10N.register(
     "Add to {instanceName}" : "{instanceName}에 더하기",
     "Title" : "직위",
     "Link" : "링크",
+    "Root folder" : "루트 폴더",
     "Tags" : "태그",
     "Notes" : "Notes",
+    "Open file" : "파일 열기",
+    "Projects" : "프로젝트",
     "Owner" : "Owner",
     "Sharing" : "공유",
     "Share link" : "링크 공유",
     "Copy link" : "링크 복사",
     "Delete link" : "링크 삭제",
     "Allow editing" : "Allow editing",
+    "Allow resharing" : "재공유 허용",
     "Link copied" : "링크 복사됨",
     "Privacy" : "프라이버시",
     "Previews" : "미리 보기",
