@@ -6,21 +6,28 @@ OC.L10N.register(
     "Move" : "Verschieben",
     "Delete" : "Läschen",
     "Select all" : "All auswielen",
+    "Go back" : "Zeréckgoen",
     "New" : "Nei",
     "New folder" : "Neien Dossier",
+    "Rename folder" : "Dossier ëmbenennen",
+    "Delete folder" : "Dossier läschen",
     "Cancel" : "Ofbriechen",
     "Recent" : "Rezent",
+    "Shared with you" : "Mat dir gedeelt",
+    "Files" : "Fichieren",
     "Import" : "Importéieren",
     "Export" : "Exportéieren",
     "Title" : "Titel",
     "Link" : "Link",
     "Tags" : "Tags",
     "Notes" : "Notizen",
+    "Open file" : "Fichier opmaachen",
     "Owner" : "Owner",
     "Sharing" : "Gedeelt",
     "Share link" : "Link deelen",
     "Copy link" : "Link kopéieren",
     "Allow editing" : "Beaarbechten erlaben",
+    "Allow resharing" : "Resharing erlaben",
     "Folder" : "Dossier",
     "Save" : "Späicheren"
 },
