@@ -41,12 +41,14 @@ OC.L10N.register(
     "Move folder" : "Perkelti aplanką",
     "Delete folder" : "Ištrinti aplanką",
     "Do you really want to delete this folder?" : "Ar tikrai norite ištrinti šį aplanką?",
+    "Choose folder" : "Pasirinkti aplanką",
     "Submit" : "Pateikti",
     "Cancel" : "Atsisakyti",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Perkeliamas %n aplankas ir keli adresyno įrašai","Perkeliami %n aplankai ir keli adresyno įrašai","Perkeliama %n aplankų ir keli adresyno įrašai","Perkeliamas %n aplankas ir keli adresyno įrašai"],
     "_Moving %n folder_::_Moving %n folders_" : ["Perkeliamas %n aplankas","Perkeliami %n aplankai","Perkeliama %n aplankų","Perkeliamas %n aplankas"],
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Perkeliamas %n adresyno įrašas","Perkeliami %n adresyno įrašai","Perkeliama %n adresyno įrašų","Perkeliamas %n adresyno įrašas"],
     "Recent" : "Paskiausi",
+    "Shared with you" : "Bendrinama su jumis",
     "Files" : "Failai",
     "New tag" : "Nauja žymė",
     "Untagged" : "Be žymių",
@@ -57,9 +59,11 @@ OC.L10N.register(
     "Add to {instanceName}" : "Pridėti į {instanceName}",
     "Title" : "Pareigos",
     "Link" : "Nuoroda",
+    "Root folder" : "Šakninis aplankas",
     "Tags" : "Žymės",
     "Notes" : "Pastabos",
     "Open file" : "Atverti failą",
+    "Projects" : "Projektai",
     "Owner" : "Savininkas",
     "Sharing" : "Bendrinimas",
     "Select a user or group" : "Pasirinkti naudotoją ar grupę",
@@ -69,6 +73,7 @@ OC.L10N.register(
     "Delete link" : "Ištrinti nuorodą",
     "Create public link" : "Sukurti viešąją nuorodą",
     "Allow editing" : "Leisti redaguoti",
+    "Allow resharing" : "Leisti bendrinti iš naujo",
     "Remove share" : "Šalinti viešinį",
     "Link copied" : "Nuoroda nukopijuota",
     "Privacy" : "Privatumas",
