@@ -10,12 +10,18 @@ OC.L10N.register(
     "Move" : "Pārvietot",
     "Delete" : "Dzēst",
     "Select all" : "Atzīmēt visu",
+    "Go back" : "Atpakaļ",
     "New" : "Jauns",
     "New folder" : "Jauna mape",
     "Add a bookmark" : "Pievienot grāmatzīmi",
+    "Rename folder" : "Pārsaukt mapi",
+    "Delete folder" : "Dzēst mapi",
+    "Choose folder" : "Izvēlies mapi",
     "Submit" : "Iesniegt",
     "Cancel" : "Atcelt",
     "Recent" : "Nesenās",
+    "Shared with you" : "Koplietots ar jums",
+    "Files" : "Datnes",
     "Import" : "Importēt",
     "Export" : "Eksportēt",
     "Bookmarklet" : "Grāmatzīme",
@@ -23,11 +29,14 @@ OC.L10N.register(
     "Link" : "Saite",
     "Tags" : "Birkas",
     "Notes" : "Piezīmes",
+    "Open file" : "Atvērt datni",
+    "Projects" : "Projekti",
     "Owner" : "Īpašnieks",
     "Sharing" : "Koplietošana",
     "Share link" : "Koplietot saiti",
     "Copy link" : "Kopēt saiti",
     "Allow editing" : "Atļaut rediģēšanu",
+    "Allow resharing" : "Atļaut atkārtotu koplietošanu",
     "Link copied" : "Saite nokopēta",
     "Privacy" : "Privātums",
     "Previews" : "Priekšskatījumi",
