@@ -6,18 +6,26 @@ OC.L10N.register(
     "Move" : "Премести",
     "Delete" : "Избриши",
     "Select all" : "Избери се",
+    "Go back" : "Назад",
+    "Share folder" : "Сподели папка",
     "New" : "Ново",
     "New folder" : "Нова папка",
     "RSS feed copied" : "RSS канал копиран",
+    "Rename folder" : "Преименувај папка",
+    "Delete folder" : "Избриши папка",
     "Submit" : "Испрати",
     "Cancel" : "Откажи",
     "Recent" : "Неодамнешни",
+    "Shared with you" : "Споделено со вас",
+    "Files" : "Датотеки",
     "Import" : "Увези",
     "Export" : "Извези",
     "Title" : "Наслов",
     "Link" : "Линк",
     "Tags" : "Ознаки",
     "Notes" : "Белешки",
+    "Open file" : "Отвори датотека",
+    "Projects" : "Проекти",
     "Owner" : "Сопственик",
     "Sharing" : "Споделување",
     "Select a user or group" : "Избери корисник или група",
@@ -25,6 +33,7 @@ OC.L10N.register(
     "Copy link" : "Копирај линк",
     "Copy RSS feed" : "Копирај RSS канал",
     "Allow editing" : "Овозможи уредување",
+    "Allow resharing" : "Дозволи повторно споделување",
     "Remove share" : "Отстрани споделување",
     "Link copied" : "Линкот е копиран",
     "Privacy" : "Приватност",
