@@ -16,20 +16,27 @@ OC.L10N.register(
     "Move" : "Зөөх",
     "Delete" : "Устгах",
     "Select all" : "бүгдийг сонгох",
+    "Go back" : "Буцах",
     "New" : "Шинэ",
     "New folder" : "Шинэ хавтас",
+    "Delete folder" : "Хавтсыг устгах",
+    "Choose folder" : "Хавтас сонгого уу",
     "Submit" : "мэдэгдэх",
     "Cancel" : "болиулах",
     "Recent" : "Сүүлийн үеийн",
+    "Shared with you" : "тантай хуваалцсан",
+    "Files" : "файлууд",
     "Import" : "Импорт",
     "Export" : "Экспорт",
     "Title" : "Цол/Албан тушаал",
     "Link" : "Холбоос",
     "Tags" : "Tag-үүд",
     "Notes" : "Шинэ ",
+    "Open file" : "Файл онгойлгох",
     "Owner" : "Эзэмшигч",
     "Sharing" : "Түгээх",
     "Share link" : "Холбоос хуваалцах",
+    "Copy link" : "Холбоос хуулах",
     "Allow editing" : "Засварлахыг зөвшөөрөх",
     "Privacy" : "Хувийн нууц",
     "Folder" : "Хавтас",
