@@ -105,6 +105,7 @@ OC.L10N.register(
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["%n bladwijzer verplaatsen","%n bladwijzers verplaatsen"],
     "All bookmarks" : "Alle bladwijzers",
     "Recent" : "Recent",
+    "Shared with you" : "Gedeeld met jou",
     "Files" : "Bestanden",
     "Broken links" : "Niet-werkende links",
     "New tag" : "Nieuwe tag",
@@ -130,6 +131,7 @@ OC.L10N.register(
     "Title" : "Titel",
     "Link" : "Link",
     "Untitled folder" : "Naamloze map",
+    "Root folder" : "Hoofdmap",
     "Tags" : "Tags",
     "Select tags and create new ones" : "Selecteer tags en maak nieuwe aan",
     "Notes" : "Notities",
@@ -137,6 +139,7 @@ OC.L10N.register(
     "Archived file" : "Gearchiveerd bestand",
     "Open file" : "Openen bestand",
     "Open file location" : "Open bestandslocatie",
+    "Projects" : "Projecten",
     "Created {time} ago" : "{time} geleden gecreëerd",
     "Created on {date}" : "Aangemaakt op {date}",
     "Owner" : "Eigenaar",
