@@ -22,23 +22,32 @@ OC.L10N.register(
     "Move" : "Move",
     "Delete" : "Suprimir",
     "Cancel selection" : "Anullar la seleccion",
+    "Go back" : "Revenir en arrière",
     "New" : "Novèl",
     "New folder" : "Novèl dorsièr",
     "Enter a link" : "Dintrar un ligam",
     "Enter a title" : "Dintrar un títol",
+    "Rename folder" : "Renomenar lo repertòri",
+    "Delete folder" : "Suprimir dossièr",
+    "Submit" : "Transmetre",
     "Cancel" : "Anullar",
     "Recent" : "Recents",
+    "Shared with you" : "Partejat amb vos",
+    "Files" : "Fichièrs",
     "Import" : "Importar",
     "Export" : "Exportar",
     "Title" : "Títol",
     "Link" : "Ligam",
     "Tags" : "Etiquetas",
     "Notes" : "Nòtas",
+    "Open file" : "Dobrir fichièr",
+    "Projects" : "Projèctes",
     "Owner" : "Owner",
     "Sharing" : "Partiment",
     "Share link" : "Partejar lo ligam",
     "Copy link" : "Copiar lo ligam",
     "Allow editing" : "Permetre la modificacion",
+    "Link copied" : "Ligam copiat",
     "Privacy" : "Confidencialitat",
     "Folder" : "Dorsièr",
     "Save" : "Salvar"
