@@ -10,9 +10,12 @@ OC.L10N.register(
     "New folder" : "نوی فولډر",
     "Cancel" : "پرېښول",
     "Recent" : "وروستي",
+    "Shared with you" : "تاسې سره شريک شوي",
+    "Files" : "فایلونه",
     "Link" : "لېنک",
     "Tags" : "نښکې",
     "Notes" : "شسیب",
+    "Open file" : "فایل پرانيستل",
     "Share link" : "د شرېکېدو لېنک",
     "Copy link" : "لېنک کاپي کول",
     "Allow editing" : "د سمون اجازه ورکول",
