@@ -7,28 +7,39 @@ OC.L10N.register(
     "Move" : "Mover",
     "Delete" : "Apagar",
     "Select all" : "Seleccionar todos",
+    "Go back" : "Voltar",
+    "Share folder" : "Partilhar pasta",
     "New" : "Novo",
     "New folder" : "Nova pasta",
     "Add a bookmark" : "Adicionar um marcador",
+    "Rename folder" : "Renomear pasta",
+    "Delete folder" : "Apagar pasta",
+    "Choose folder" : "Escolher pasta",
     "Submit" : "Submeter",
     "Cancel" : "Cancelar",
     "All bookmarks" : "Todos os marcadores",
     "Recent" : "Recentes",
+    "Shared with you" : "Partilhado consigo",
+    "Files" : "Ficheiros",
     "Import" : "Importar",
     "Export" : "Exportar",
     "Title" : "Título",
     "Link" : "Link",
+    "Root folder" : "Pasta raiz",
     "Tags" : "Marcações",
     "Notes" : "Notas",
+    "Open file" : "Abrir ficheiro",
     "Owner" : "Proprietário",
     "Sharing" : "Partilha",
     "Select a user or group" : "Selecionar utilizador ou grupo",
     "Share link" : "Share link",
     "Copy link" : "Copiar hiperligação",
     "Allow editing" : "Permitir edição",
+    "Allow resharing" : "Permitir repartilha",
     "Link copied" : "Link copiado",
     "Privacy" : "Privacidade",
+    "Failed to save settings" : "Erro ao gravar as definições",
     "Folder" : "Pasta",
     "Save" : "Guardar"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
