@@ -6,22 +6,32 @@ OC.L10N.register(
     "Move" : "Mută",
     "Delete" : "Șterge",
     "Select all" : "Selectează tot",
+    "Go back" : "Înapoi",
+    "Share folder" : "Distribuie dosar",
     "New" : "Nou",
     "New folder" : "Director nou",
+    "Rename folder" : "Redenumește dosar",
+    "Delete folder" : "Șterge director",
     "Submit" : "Trimite",
     "Cancel" : "Anulează",
     "Recent" : "Recente",
+    "Shared with you" : "Partajat cu tine",
+    "Files" : "Fișiere",
     "Import" : "Importă",
     "Export" : "Exportă",
     "Title" : "Titlu",
     "Link" : "Legătură",
+    "Root folder" : "Folder principal",
     "Tags" : "Etichete",
     "Notes" : "Notițe",
+    "Open file" : "Deschide fișier",
+    "Projects" : "Proiecte",
     "Owner" : "Proprietar",
     "Sharing" : "Partajare",
     "Share link" : "Partajează link-ul",
     "Copy link" : "Copiază link",
     "Allow editing" : "Permite editarea",
+    "Allow resharing" : "Permite repartajarea",
     "Link copied" : "Link copiat",
     "Privacy" : "Confindențialitate",
     "Folder" : "Director",
