@@ -105,6 +105,7 @@ OC.L10N.register(
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Перемещаем %n закладку","Перемещаем %n закладок","Перемещаем %n закладок","Перемещаем %n закладок"],
     "All bookmarks" : "Все закладки",
     "Recent" : "Недавние",
+    "Shared with you" : "Поделился с вами",
     "Files" : "Файлы",
     "Broken links" : "Нерабочие ссылки",
     "New tag" : "Новый тег",
@@ -130,6 +131,7 @@ OC.L10N.register(
     "Title" : "Название",
     "Link" : "Ссылка",
     "Untitled folder" : "Папка без названия",
+    "Root folder" : "Корневая папка",
     "Tags" : "Метки",
     "Select tags and create new ones" : "Выбрать метки и создать новую",
     "Notes" : "Заметки",
@@ -137,6 +139,7 @@ OC.L10N.register(
     "Archived file" : "Архивный файл",
     "Open file" : "Открыть файл",
     "Open file location" : "Открыть расположение файла",
+    "Projects" : "Проекты",
     "Created {time} ago" : "Время создания: {time}",
     "Created on {date}" : "Дата создания: {date}",
     "Owner" : "Владелец",
