@@ -101,6 +101,7 @@ OC.L10N.register(
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Tràmuda %n signalibru","Tràmuda %n signalibros"],
     "All bookmarks" : "Totu is signalibros",
     "Recent" : "Reghente",
+    "Shared with you" : "Cumpartzidu cun tegus",
     "Files" : "Archìvios",
     "Broken links" : "Ligòngios segados",
     "New tag" : "Eticheta noa",
@@ -123,6 +124,7 @@ OC.L10N.register(
     "Please select \"Add to home screen\" in your browser menu" : "Pro praghere, seletziona \"Agiunghe a s'ischermada printzipale\" in su menu de su navigadore tuo",
     "Title" : "Tìtulu",
     "Link" : "Ligòngiu",
+    "Root folder" : "Cartella sorgente",
     "Tags" : "Etichetas",
     "Select tags and create new ones" : "Seletziona etichetas e crea·nde àteras noas",
     "Notes" : "Notas",
@@ -130,6 +132,7 @@ OC.L10N.register(
     "Archived file" : "Documentu archiviadu",
     "Open file" : "Aberi archìviu",
     "Open file location" : "Aberi positzione de s'archìviu",
+    "Projects" : "Progetos",
     "Created {time} ago" : "Creadu {time} a immoe",
     "Created on {date}" : "Creadu su {date}",
     "Owner" : "Mere",
