@@ -5,17 +5,21 @@ OC.L10N.register(
     "Rename" : "නැවත නම් කරන්න",
     "Select all" : "සියල්ල තෝරන්න",
     "Cancel selection" : "තේරීම අවලංගු කරන්න",
+    "Go back" : "ආපසු යන්න",
     "New" : "නව",
     "New folder" : "නව බහාලුම",
     "Enter a link" : "සබැඳියක් ඇතුළත් කරන්න",
     "Select folder" : "බහාලුම තෝරන්න",
     "Cancel" : "අවලංගු කරන්න",
+    "Files" : "ගොනු",
     "Link" : "සබැඳිය",
     "Notes" : "සටහන්",
+    "Open file" : "ගොනුව විවෘත කරන්න",
     "Owner" : "හිමිකරු",
     "Select a user or group" : "පරිශීලකයෙකු හෝ සමූහයක් තෝරන්න",
     "Copy link" : "සබැඳිය පිටපත් කරන්න",
     "Allow editing" : "සංස්කරණයට ඉඩ දෙන්න",
+    "Allow resharing" : "නැවත බෙදා ගැනීමට ඉඩ දෙන්න",
     "Link copied" : "සබැඳිය පිටපත් කළා",
     "Privacy" : "පෞද්ගලිකත්වය",
     "Folder" : "බහාලුම",
