@@ -130,6 +130,9 @@ OC.L10N.register(
     "Export" : "Export",
     "Archive path" : "Archivovať cestu",
     "Enter the path of a folder in your Files where bookmarked files should be stored." : "Vložte cestu k priečinku kde sa budú ukladať súbory v záložkách.",
+    "Backups" : "Zálohy",
+    "Enable bookmarks backups" : "Povoliť zálohovanie záložiek",
+    "Enter the path of a folder in your Files where backups will be stored." : "Vložte cestu k priečinku kde sa budú ukladať zálohy.",
     "Client apps" : "Aplikácie klienta",
     "Also check out the collection of client apps that integrate with this app: " : "Pozrite si sadu klientskych aplikácií, ktoré sa integrujú do tejto aplikácie:",
     "Install web app on device" : "Nainštalovať webovú aplikáciu na zariadenie",
