@@ -6,11 +6,17 @@ OC.L10N.register(
     "Move" : "Zhvendos",
     "Delete" : "Fshij",
     "Select all" : "Zgjidhi të gjitha",
+    "Go back" : "Shko prapa",
     "New" : "I ri",
     "New folder" : "Dosje e re",
+    "Rename folder" : "Riemërtoni dosjen",
+    "Delete folder" : "Fshini dosjen",
+    "Choose folder" : "Zgjidhni dosjen",
     "Submit" : "Dërgo",
     "Cancel" : "Anullo",
     "Recent" : "Së fundmi",
+    "Shared with you" : "E ndarë me ju",
+    "Files" : "Skedarët",
     "Untagged" : "E paetiketuar",
     "Import" : "Import",
     "Export" : "Eksport",
@@ -19,11 +25,13 @@ OC.L10N.register(
     "Link" : "Lidhje",
     "Tags" : "Etiketat",
     "Notes" : "Shënime",
+    "Open file" : "Hap skedarin",
     "Owner" : "Zotëruesi",
     "Sharing" : "Ndarje",
     "Share link" : "Share link",
     "Copy link" : "Kopjo linkun",
     "Allow editing" : "Lejo redaktimin",
+    "Allow resharing" : "Lejo rindarje",
     "Link copied" : "Linku u kopjua",
     "Privacy" : "Privatësia",
     "Previews" : "Parapamjet",
