@@ -19,6 +19,7 @@ OC.L10N.register(
     "Selected {folders} folders and {bookmarks} bookmarks" : "Одабрано {folders} фасцикла(е) и {bookmarks} обележивач(а)",
     "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Одабрано %n обележивач","Одабрано %n обележивача","Одабрано %n обележивача"],
     "_Selected %n folder_::_Selected %n folders_" : ["Одабрана %n фасцикла","Одабране %n фасцикле","Одабрано %n фасцикли"],
+    "Go back" : "Иди назад",
     "Select one or more tags" : "Одаберите једну или више ознака",
     "New" : "Нов",
     "New bookmark" : "Нови обележивач",
@@ -29,6 +30,9 @@ OC.L10N.register(
     "Select folder" : "Одабери фасциклу",
     "Enter folder title" : "Унесите назив фасцикле",
     "Shared by {user}" : "Поделио {user}",
+    "Rename folder" : "Преименуј фасциклу",
+    "Delete folder" : "Обриши фасциклу",
+    "Choose folder" : "Одаберите фасциклу",
     "Submit" : "Пошаљи",
     "Cancel" : "Поништи",
     "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Премештам %n фасциклу и неке обележиваче","Премештам %n фасцикле и неке обележиваче","Премештам %n фасцикли и неке обележиваче"],
@@ -36,6 +40,8 @@ OC.L10N.register(
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Премештам %n обележивач","Премештам %n обележивача","Премештам %n обележивача"],
     "All bookmarks" : "Све забелешке",
     "Recent" : "Скорашње",
+    "Shared with you" : "Дељено са Вама",
+    "Files" : "Фајлови",
     "Untagged" : "Неозначени",
     "{used} bookmarks of {available} available" : "Искоришћено {used} од {available} доступних обележивача",
     "No bookmarks here" : "Овде нема обележивача",
@@ -47,8 +53,11 @@ OC.L10N.register(
     "Add to {instanceName}" : "Додај на {instanceName} ",
     "Title" : "Наслов",
     "Link" : "Веза",
+    "Root folder" : "Корена фасцикла",
     "Tags" : "Ознаке",
     "Notes" : "Белешке",
+    "Open file" : "Отвори фајл",
+    "Projects" : "Пројекти",
     "Owner" : "Власник",
     "Sharing" : "Дељење",
     "Select a user or group" : "Одаберите корисника или групу",
@@ -58,6 +67,7 @@ OC.L10N.register(
     "Delete link" : "Обриши везу",
     "Create public link" : "Направи јавну везу",
     "Allow editing" : "Дозволи уређивање",
+    "Allow resharing" : "Дозволи дељење даље",
     "Remove share" : "Уклони дељење",
     "Link copied" : "Веза ископирана",
     "Privacy" : "Приватност",
