@@ -9,11 +9,15 @@ OC.L10N.register(
     "New" : "Nov",
     "New folder" : "Nova fascikla",
     "Cancel" : "Otkaži",
+    "Shared with you" : "Shared with you",
+    "Files" : "Фајлови",
     "Import" : "Uvezi",
     "Title" : "Naslov",
     "Link" : "Prečica",
+    "Root folder" : "Korena fascikla",
     "Tags" : "Oznake",
     "Notes" : "Notes",
+    "Open file" : "Отвори фајл",
     "Owner" : "Vlasnik",
     "Sharing" : "Deljenje",
     "Share link" : "Podeli vezu",
