@@ -101,6 +101,7 @@ OC.L10N.register(
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Flyttar %n bokmärke","Flyttar %n bokmärken"],
     "All bookmarks" : "Alla bokmärken",
     "Recent" : "Nya",
+    "Shared with you" : "Delat med dig",
     "Files" : "Filer",
     "Broken links" : "Brutna länkar",
     "New tag" : "Ny tagg",
@@ -123,6 +124,7 @@ OC.L10N.register(
     "Please select \"Add to home screen\" in your browser menu" : "Vänligen välj \"Lägg till hemskärm\" i din webbläsarmeny",
     "Title" : "Titel",
     "Link" : "Länk",
+    "Root folder" : "Topp-mapp",
     "Tags" : "Taggar",
     "Select tags and create new ones" : "Välj taggar och skapa nya",
     "Notes" : "Anteckning",
@@ -130,6 +132,7 @@ OC.L10N.register(
     "Archived file" : "Arkiverad fil",
     "Open file" : "Öppna fil",
     "Open file location" : "Öppna filsökväg",
+    "Projects" : "Projekt",
     "Created {time} ago" : "Skapad för {time} sedan",
     "Created on {date}" : "Skapades {date}",
     "Owner" : "Ägare",
