@@ -6,20 +6,32 @@ OC.L10N.register(
     "Move" : "Move",
     "Delete" : "ลบ",
     "Select all" : "เลือกทั้งหมด",
+    "Go back" : "กลับไป",
+    "Share folder" : "แชร์โฟลเดอร์",
     "New" : "ใหม่",
     "New folder" : "โฟลเดอร์ใหม่",
+    "Rename folder" : "เปลี่ยนชื่อโฟลเดอร์",
+    "Delete folder" : "ลบโฟลเดอร์",
+    "Submit" : "ส่ง",
     "Cancel" : "ยกเลิก",
+    "Recent" : "ล่าสุด",
+    "Shared with you" : "แชร์กับคุณ",
+    "Files" : "ไฟล์",
     "Import" : "นำเข้า",
     "Export" : "ส่งออก",
     "Title" : "ชื่อเรื่อง",
     "Link" : "ลิงค์",
     "Tags" : "ป้ายกำกับ",
     "Notes" : "บันทึกย่อ",
+    "Open file" : "เปิดไฟล์",
     "Owner" : "Owner",
     "Sharing" : "แชร์ข้อมูล",
     "Share link" : "แชร์ลิงค์",
     "Copy link" : "คัดลอกลิงค์",
     "Allow editing" : "อนุญาตให้แก้ไข",
+    "Allow resharing" : "อนุญาตให้แชร์ซ้ำ",
+    "Link copied" : "คัดลอกลิงก์แล้ว",
+    "Privacy" : "ความเป็นส่วนตัว",
     "Folder" : "แฟ้มเอกสาร",
     "Save" : "บันทึก"
 },
