@@ -9,24 +9,32 @@ OC.L10N.register(
     "Move" : "Перемістити",
     "Delete" : "Вилучити",
     "Select all" : "Вибрати все",
+    "Go back" : "Повернутися назад",
     "New" : "Створити",
     "New folder" : "Нова тека",
     "Add a bookmark" : "Додати закладку",
+    "Rename folder" : "Переіменувати теку",
+    "Delete folder" : "Вилучити теку",
     "Submit" : "Гаразд",
     "Cancel" : "Скасувати",
     "Recent" : "Нещодавні",
+    "Shared with you" : "Вам надано доступ",
+    "Files" : "Робота з файлами",
     "Import" : "Імпорт",
     "Export" : "Експорт",
     "Title" : "Назва",
     "Link" : "Посилання",
     "Tags" : "Позначки",
     "Notes" : "Нотатки",
+    "Open file" : "Відкрити файл",
+    "Projects" : "Проєкти",
     "Owner" : "Власник",
     "Sharing" : "Поділитись",
     "Select a user or group" : "Виберіть користувача або групу",
     "Share link" : "Поширити посилання",
     "Copy link" : "Скопіювати посилання",
     "Allow editing" : "Дозволити редагування",
+    "Allow resharing" : "Можете ділитися",
     "Link copied" : "Посилання скопійовано",
     "Privacy" : "Конфіденційність",
     "Failed to save settings" : "Неможливо зберегти налаштування",
