@@ -7,25 +7,35 @@ OC.L10N.register(
     "Move" : "Dịch chuyển",
     "Delete" : "Xóa",
     "Select all" : "Chọn tất cả",
+    "Go back" : "Quay lại",
     "Select one or more tags" : "Chọn một hoặc nhiều thẻ",
     "New" : "Tạo mới",
     "New folder" : "Tạo thư mục",
     "Add a bookmark" : "Thêm một bookmark",
     "Enter folder title" : "Nhập tiêu đề thư mục",
+    "Rename folder" : "Đổi tên thư mục",
+    "Delete folder" : "Xóa thư mục",
     "Submit" : "Gửi đi",
     "Cancel" : "Hủy bỏ",
     "Recent" : "Gần đây",
+    "Shared with you" : "Đã chia sẻ với bạn",
+    "Files" : "Tệp",
     "Import" : "Nhập vào",
     "Export" : "Xuất ra",
     "Title" : "Tên",
     "Link" : "Liên kết",
+    "Root folder" : "Thư mục gốc",
     "Tags" : "Thẻ",
     "Notes" : "Ghi chép",
+    "Open file" : "Mở tệp",
+    "Projects" : "Dự án",
     "Owner" : "Chủ",
     "Sharing" : "Đang chia sẽ",
     "Share link" : "Chia sẽ liên kết",
     "Copy link" : "Sao chép liên kết",
     "Allow editing" : "Cho phép chỉnh sửa",
+    "Allow resharing" : "Cho phép chia sẻ lại",
+    "Link copied" : "Đã sao chép liên kết",
     "Privacy" : "Riêng tư",
     "Failed to save settings" : "Lưu cấu hình thất bại",
     "Failed to load settings" : "Tải cấu hình thất bại",
