@@ -105,6 +105,7 @@ OC.L10N.register(
     "_Moving %n bookmark_::_Moving %n bookmarks_" : ["正在移动%n个书签"],
     "All bookmarks" : "全部书签",
     "Recent" : "最近",
+    "Shared with you" : "已共享给您",
     "Files" : "文件",
     "Broken links" : "失效的链接",
     "New tag" : "新标签",
@@ -130,6 +131,7 @@ OC.L10N.register(
     "Title" : "标题",
     "Link" : "链接",
     "Untitled folder" : "未命名文件夹",
+    "Root folder" : "根文件夹",
     "Tags" : "标签",
     "Select tags and create new ones" : "选择和生成标记",
     "Notes" : "笔记",
@@ -137,6 +139,7 @@ OC.L10N.register(
     "Archived file" : "已存档的文件",
     "Open file" : "打开文件 ",
     "Open file location" : "打开文件位置 ",
+    "Projects" : "项目",
     "Created {time} ago" : "创建于 {time} 之前",
     "Created on {date}" : "创建于 {date}",
     "Owner" : "拥有者",
